"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ghMdBatchRender = void 0;
const rest_1 = require("@octokit/rest");
const numbers = Array.from({ length: 10 }, (_, i) => i.toString());
const upperCaseLetters = Array.from({ length: 26 }, (_, i) => String.fromCharCode(i + 65));
const lowerCaseLetters = Array.from({ length: 26 }, (_, i) => String.fromCharCode(i + 97));
const base62Mapping = numbers.concat(upperCaseLetters, lowerCaseLetters);
const getBase62Char = (n) => base62Mapping[n];
const getRandomBase62Char = () => getBase62Char(Math.floor(Math.random() * 62));
const getRandomBase62Str = (length) => Array(length).fill(null).map(getRandomBase62Char).join('');
/**
 * Batch-render markdowns via GitHub-API.
 *
 * Useful for mitigating GitHub's request rate-limit.
 * @param markdowns Array of markdown strings to render.
 * @param options Octokit options.
 * @returns Array of rendered markdown strings.
 */
const ghMdBatchRender = (markdowns, options = {}) => __awaiter(void 0, void 0, void 0, function* () {
    const { mode = 'gfm', context, octokit = new rest_1.Octokit() } = options;
    const base62Str = getRandomBase62Str(30);
    const separator = '\n\n' + base62Str + '\n\n';
    const htmlStr = yield octokit.rest.markdown
        .render({ text: markdowns.join(separator), mode, context })
        .then((x) => x.data);
    return htmlStr.split(new RegExp(`\n<p[^>]*>${base62Str}<\\/p>\n`));
});
exports.ghMdBatchRender = ghMdBatchRender;
